-- uses spritebatch for source of cards

local gr	= love.graphics
local c		= require 'cards'
local r		= require 'Roman'
-- Parameterss:
--	firstSelection = true = first selection, false second selection
--	deck = deck of cards in order - clubs{A-K),spades(A-K),heart(A-K)s,diamonds(A-K)
--	order = shuffled index for deck
--	dl = table of parameters needed for card dealing
--	chk determines which cards to draw
--	pos determines which cards are covered - # cards minus 1 or 2 revealed

local dl = {							-- card dealing (tweening parameters)
		lapse	= 0,
		start	= { 400, 800 },
		final	= { 10, 10 },
		dur		= 0.2,
		cx		= 0,
		cy		= 0
		}

function love.load()
	gr.setBackgroundColor( 0, 55, 0, 255 )
	love.window.setMode( 1000, 800 )
	gr.setFont(gr.newFont(20))
	r.load()

	initialize()
	cheat		= false
	end

function initialize()
	deck, order	= c:createDeck()
	dl.active	= true				-- dealing in process
	dl.done		= false				-- deal not done
	dl.x		= 0
	dl.y		= 0
	pos			= {}				-- cards to be covered
	mx, my, pressed = 0, 0, false
	xx, yy		= 1, 1				-- dummy settings
	txx			= 10				-- upper left corner
	tyy			= 10
	firstSelection = true
	chk			= {}				-- cards to be drawn = 1
	for i		= 1, 52 do chk[i] = 1 end
	cards		= c.create_hands()
	click		= 0
	time		= 0
	end

function love.update( dt )
	if dl.done then time = time + dt end
	dealCards( dt )
	if dl.done and pressed then	-- press left mouse to select card pairs
		if firstSelection then
			if chk[ order[ xx ] ] == 1 then pos[ xx ][ 1 ] = txx end
			if chk[ order[ yy ] ] == 1 then pos[ yy ][ 1 ] = tyy end
			xx = math.floor( mx / 75 ) +13 * math.floor( my / 100 ) +1
			txx = pos[ xx ][ 1 ]
			pos[ xx ][ 1 ] = 0	-- show card
			firstSelection = false
			else
			yy = math.floor( mx / 75 ) + 13 * math.floor( my / 100 ) +1
			tyy = pos[ yy ][1]
			pos[ yy ][ 1 ] = 0	-- show card
			firstSelection = true
			end
		pressed = false
	-- check for matched cards
		if order[ xx ] > order[ yy ] then
			if order[ xx ] - order[ yy ]== 26 then
				chk[ order[ xx ] ]		= 0
				chk[ order[ yy ] ]		= 0
				end
			else
			if order[ yy ] - order[ xx ]== 26 then
				chk[ order[ xx ] ]		= 0
				chk[ order[ yy ] ]		= 0
				end
			end
		end
	comp = 0
	for i = 1, #chk do comp = comp + chk[i] end
	if comp < 1 then initialize() end	-- level complete - restart
	end

function love.keypressed( key )
	if key == 'escape'	then love.event.quit() 	end
	if key == 'c'		then cheat = not cheat end
	end

function love.draw()
	gr.setColor( 255, 255, 255, 255 )
	if dl.done then c.showCards( cards ) end	-- draw cards
	-- draw animated dealing of card
	if dl.active and not dl.done then c.draw( backred,dl.cx,dl.cy ) end
	-- draw covering card for those not already selected
	for i = 1, #pos do
		if pos[i][1] > 0 and chk[order[i]]~= 0 then
			c.draw( backred, pos[i][2], pos[i][1] )
			end
		end
	gr.print( 'Number of clicks: '..click, 750, 700 )
	time2=r.convert(math.floor(time))
	gr.print( 'Lapsed time: '..time2,10,700)
	if dl.done and cheat then
		gr.setColor( 155, 155, 155, 180 )
		c.showCards( cards )
		end
	end

function love.mousepressed( x, y, button )
	if button	== "l" then
		mx		= x < 915 and x or 915	-- limit range fo cards
		my		= y < 380 and y or 380
		pressed = true
		click	= click + 1
		end
	end

function dealCards( dt )
	if dl.active then
		dl.lapse = dl.lapse + dt
		dl.cx, dl.cy = c.outQuint_deal( dl.lapse, dl.start[1], dl.final[1], dl.start[2], dl.final[2], dl.dur )
		if  dl.cy == dl.final[2] then dl.active = false end
		else
		if not dl.done then
			pos[#pos+1] = { 100 * dl.y + 10, 75 * dl.x + 10 }
			dl.x		= dl.x + 1
			if dl.x		> 12 then dl.x = 0 dl.y = dl.y + 1 end
			if dl.y		== 4 then
				dl.done = true
				dl.active = false
				else
				dl.final = { 75 * dl.x + 10, 100 * dl.y + 10 }
				dl.start = { 400, 800 }
				dl.lapse = 0
				dl.active = true
				end
			end
		end
	end

